RealisticFlipbook class

Inheritance

Constructors

RealisticFlipbook({Key? key, required List<FlipbookPage?> pages, FlipbookController? controller, Duration flipDuration = const Duration(milliseconds: 1000), Duration zoomDuration = const Duration(milliseconds: 500), List<double> zooms = const <double>[1, 2, 4], double perspective = 2400, int nPolygons = 10, double ambient = 0.4, double gloss = 0.6, double swipeMin = 3, bool singlePage = false, FlipbookForwardDirection forwardDirection = FlipbookForwardDirection.right, bool centering = true, int? startPage, double flipThreshold = 0.15, bool allowPageWidgetGestures = false, bool tapToFlip = true, bool clickToZoom = true, bool dragToFlip = true, bool dragToScroll = true, FlipbookWheelMode wheel = FlipbookWheelMode.scroll, bool clipToViewport = true, bool singlePageSpreadNavigation = true, Duration singlePageSlideDuration = const Duration(milliseconds: 320), Color paperColor = Colors.white, bool bookChrome = false, double bookTopInsetRatio = 0.075, double bookBottomInsetRatio = 0.085, double bookSideInsetRatio = 0.045, TextStyle? bookHeaderStyle, TextStyle? bookFooterStyle, Color bookHeaderFooterColor = const Color(0xFF6D4C1E), Color bookBorderColor = const Color(0xFFC8A86F), Color bookInnerBorderColor = const Color(0xFFEAD3A5), double bookShadowStrength = 0.22, Color blankPageColor = const Color(0xFFDDDDDD), WidgetBuilder? loadingBuilder, FlipbookPageCallback? onFlipLeftStart, FlipbookPageCallback? onFlipLeftEnd, FlipbookPageCallback? onFlipRightStart, FlipbookPageCallback? onFlipRightEnd, FlipbookZoomCallback? onZoomStart, FlipbookZoomCallback? onZoomEnd, FlipbookFlipGuardCallback? onFlipGuard})
const

Properties

allowPageWidgetGestures bool
final
ambient double
final
blankPageColor Color
final
bookBorderColor Color
final
bookBottomInsetRatio double
final
bookChrome bool
final
bookFooterStyle TextStyle?
final
bookHeaderFooterColor Color
final
bookHeaderStyle TextStyle?
final
bookInnerBorderColor Color
final
bookShadowStrength double
final
bookSideInsetRatio double
final
bookTopInsetRatio double
final
centering bool
final
clickToZoom bool
final
clipToViewport bool
final
controller FlipbookController?
final
dragToFlip bool
final
dragToScroll bool
final
flipDuration Duration
final
flipThreshold double
final
forwardDirection FlipbookForwardDirection
final
gloss double
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder WidgetBuilder?
final
nPolygons int
final
onFlipGuard FlipbookFlipGuardCallback?
final
onFlipLeftEnd FlipbookPageCallback?
final
onFlipLeftStart FlipbookPageCallback?
final
onFlipRightEnd FlipbookPageCallback?
final
onFlipRightStart FlipbookPageCallback?
final
onZoomEnd FlipbookZoomCallback?
final
onZoomStart FlipbookZoomCallback?
final
pages List<FlipbookPage?>
final
paperColor Color
final
perspective double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singlePage bool
final
singlePageSlideDuration Duration
final
singlePageSpreadNavigation bool
final
startPage int?
final
swipeMin double
final
tapToFlip bool
final
wheel FlipbookWheelMode
final
zoomDuration Duration
final
zooms List<double>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RealisticFlipbook>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited